@@ -18,9 +18,9 @@ class AllowedCapabilitiesSysAdmin(BaseK8Check):
         return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
-        if "securityContext" in conf:
-            if "capabilities" in conf["securityContext"]:
-                if "add" in conf["securityContext"]["capabilities"]:
+        if conf.get("securityContext"):
+            if conf["securityContext"].get("capabilities"):
+                if conf["securityContext"]["capabilities"].get("add"):
                     if "SYS_ADMIN" in conf["securityContext"]["capabilities"]["add"]:
                         return CheckResult.FAILED
         return CheckResult.PASSED
