@@ -20,17 +20,19 @@ class ImageDigest(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return conf['parent']
+        return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
         if "image" in conf:
 
             # The @ indicates there is a digest. It's technically possible to use a tag as well, but it doesn't make
             # a difference. So, this @ is all we need to pass the check.
-            has_digest = '@' in conf["image"]
-            return CheckResult.PASSED if has_digest else CheckResult.FAILED
+            image_conf = conf["image"]
+            if isinstance(image_conf,str):
+                has_digest = '@' in image_conf
+                return CheckResult.PASSED if has_digest else CheckResult.FAILED
         else:
             return CheckResult.FAILED
 
 
-check = ImageDigest()
\ No newline at end of file
+check = ImageDigest()
