@@ -1,5 +1,6 @@
+from checkov.common.util.type_forcers import force_list
 from checkov.terraform.checks.data.base_check import BaseDataCheck
-from checkov.terraform.models.enums import CheckResult, CheckCategories
+from checkov.common.models.enums import CheckResult, CheckCategories
 
 
 class AdminPolicyDocument(BaseDataCheck):
@@ -7,7 +8,7 @@ class AdminPolicyDocument(BaseDataCheck):
         name = "Ensure IAM policies that allow full \"*-*\" administrative privileges are not created"
         id = "CKV_AWS_1"
         supported_data = ['aws_iam_policy_document']
-        categories = [CheckCategories.GENERAL_SECURITY]
+        categories = [CheckCategories.IAM]
         super().__init__(name=name, id=id, categories=categories, supported_data=supported_data)
 
     def scan_data_conf(self, conf):
@@ -19,8 +20,12 @@ class AdminPolicyDocument(BaseDataCheck):
         """
         key = 'statement'
         if key in conf.keys():
-            if '*' == conf[key][0]['actions'][0] and '*' == conf[key][0]['resources'][0]:
-                return CheckResult.FAILED
+            for statement in conf[key]:
+                effect = statement.get('effect', ['Allow'])
+                if not effect or effect[0] == 'Allow':
+                    if statement.get('actions') and '*' in force_list(statement['actions'][0]) \
+                        and statement.get('resources') and '*' in force_list(statement['resources'][0]):
+                        return CheckResult.FAILED
         return CheckResult.PASSED
 
 
