@@ -1,9 +1,9 @@
 import json
-import logging
 
 import yaml
 
 from checkov.common.models.enums import CheckResult, CheckCategories
+from checkov.common.util.type_forcers import is_json, is_yaml
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 
 
@@ -36,22 +36,4 @@ class SSMSessionManagerDocumentEncryption(BaseResourceCheck):
         return CheckResult.UNKNOWN
 
 
-def is_json(data):
-    try:
-        json.loads(data)
-    except ValueError:
-        logging.debug(f"could not parse json data: {data}")
-        return False
-    return True
-
-
-def is_yaml(data):
-    try:
-        yaml.safe_load(data)
-    except yaml.YAMLError:
-        logging.debug(f"could not parse yaml data: {data}")
-        return False
-    return True
-
-
 check = SSMSessionManagerDocumentEncryption()
